@@ -11,11 +11,10 @@
 ! *****************************************************************************
 INTERFACE check_rotmat_der
    SUBROUTINE check_rotmat_der( sepi, sepj, rjiv, ij_matrix, do_invert, error)
-     USE f77_blas
      USE kinds,                           ONLY: dp
      USE semi_empirical_types,            ONLY: rotmat_type,&
                                                 semi_empirical_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
      IMPLICIT NONE
      TYPE(semi_empirical_type), POINTER       :: sepi, sepj
      REAL(KIND=dp), DIMENSION(3), INTENT(IN)  :: rjiv
@@ -36,12 +35,11 @@ END INTERFACE check_rotmat_der
 INTERFACE check_dssss_nucint_ana
   SUBROUTINE check_dssss_nucint_ana (sepi,sepj,r,dssss,itype,se_int_control,&
        se_taper,error)
-    USE f77_blas
     USE kinds,                           ONLY: dp
     USE semi_empirical_types,            ONLY: semi_empirical_type,&
                                                se_int_control_type,&
                                                se_taper_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
     IMPLICIT NONE
     TYPE(semi_empirical_type), POINTER       :: sepi, sepj
     REAL(dp), INTENT(IN)                     :: r
@@ -64,12 +62,11 @@ END INTERFACE check_dssss_nucint_ana
 INTERFACE check_dcore_nucint_ana
   SUBROUTINE check_dcore_nucint_ana (sepi,sepj,r,dcore,itype,se_int_control,&
        se_taper,error)
-    USE f77_blas
     USE kinds,                           ONLY: dp
     USE semi_empirical_types,            ONLY: semi_empirical_type,&
                                                se_int_control_type,&
                                                se_taper_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
     IMPLICIT NONE
     TYPE(semi_empirical_type), POINTER       :: sepi, sepj
     REAL(dp), INTENT(IN)                     :: r
@@ -92,12 +89,11 @@ END INTERFACE check_dcore_nucint_ana
 INTERFACE check_drotnuc_ana
    SUBROUTINE check_drotnuc_ana(sepi, sepj, rijv, itype, se_int_control, se_taper,&
         e1b, e2a, de1b, de2a, error)
-    USE f77_blas
     USE kinds,                           ONLY: dp
     USE semi_empirical_types,            ONLY: semi_empirical_type,&
                                                se_int_control_type,&
                                                se_taper_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
     IMPLICIT NONE
     TYPE(semi_empirical_type), POINTER       :: sepi, sepj
     REAL(dp), DIMENSION(3), INTENT(IN)       :: rijv
@@ -123,12 +119,11 @@ END INTERFACE check_drotnuc_ana
 INTERFACE check_dcorecore_ana
   SUBROUTINE check_dcorecore_ana(sepi, sepj, rijv, itype,se_int_control,&
        se_taper, enuc, denuc, error)
-    USE f77_blas
     USE kinds,                           ONLY: dp
     USE semi_empirical_types,            ONLY: semi_empirical_type,&
                                                se_int_control_type,&
                                                se_taper_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
     IMPLICIT NONE
     TYPE(semi_empirical_type), POINTER       :: sepi, sepj
     REAL(dp), DIMENSION(3), INTENT(IN)       :: rijv
@@ -154,12 +149,11 @@ END INTERFACE check_dcorecore_ana
 INTERFACE rot_2el_2c_first_debug
   SUBROUTINE rot_2el_2c_first_debug(sepi, sepj, rijv, se_int_control, se_taper,&
        invert, ii, kk, v_d, error)
-    USE f77_blas
     USE kinds,                           ONLY: dp
     USE semi_empirical_types,            ONLY: semi_empirical_type,&
                                                se_int_control_type,&
                                                se_taper_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
     IMPLICIT NONE
     TYPE(semi_empirical_type), POINTER       :: sepi, sepj
     REAL(KIND=dp), DIMENSION(3), INTENT(IN)  :: rijv
@@ -183,12 +177,11 @@ END INTERFACE rot_2el_2c_first_debug
 ! *****************************************************************************
 INTERFACE check_dterep_ana
   SUBROUTINE check_dterep_ana (sepi,sepj,r,ri,dri,se_int_control,se_taper,lgrad,error)
-    USE f77_blas
     USE kinds,                           ONLY: dp
     USE semi_empirical_types,            ONLY: semi_empirical_type,&
                                                se_int_control_type,&
                                                se_taper_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
     IMPLICIT NONE
     TYPE(semi_empirical_type), POINTER       :: sepi, sepj
     REAL(dp), INTENT(IN)                     :: r
@@ -210,12 +203,11 @@ END INTERFACE check_dterep_ana
 ! *****************************************************************************
 INTERFACE check_rotint_ana
   SUBROUTINE check_rotint_ana(sepi,sepj,rijv,w,dw,se_int_control,se_taper,error)
-    USE f77_blas
     USE kinds,                           ONLY: dp
     USE semi_empirical_types,            ONLY: semi_empirical_type,&
                                                se_int_control_type,&
                                                se_taper_type
-#include "cp_common_uses.h"
+#include "./common/cp_common_uses.f90"
     IMPLICIT NONE
     TYPE(semi_empirical_type), POINTER       :: sepi, sepj
     REAL(dp), DIMENSION(3), INTENT(IN)       :: rijv
