@@ -9,6 +9,7 @@
 ! 6) multrec 3
 ! 7) multrec 4
 ! 8) Vector version
+! 9) Intel Xeon Phi C intrinsics
 !
 MODULE multrec_gen
   USE mults
@@ -76,24 +77,39 @@ CONTAINS
     CHARACTER(LEN=*), OPTIONAL :: stack_size_label
     INTEGER, OPTIONAL :: Cbuffer_row, Cbuffer_col
 
-    IF (PRESENT(stack_size_label).AND.stack_size_label/="") THEN
-       write(6,'(A,I0,A,I0,A,I0,A)') "   SUBROUTINE smm_"//trstr(transpose_flavor,data_type)//"_",&
-            M,"_",N,"_",K,"_stack"//TRIM(label)//"("//TRIM(trparam(stack_size_label))//")"
-       CALL write_stack_params(data_type,stack_size_label)
-       write(6,'(A)')                    "      INTEGER            :: sp"
-       IF (PRESENT(Cbuffer_row).AND.PRESENT(Cbuffer_col)) THEN
-          write(6,'(A,I0,A,I0,A)')   "       "//trdat(data_type)//":: Cbuffer(",Cbuffer_row,",",Cbuffer_col,")"
+    IF (PRESENT(stack_size_label)) THEN
+       IF (stack_size_label/="") THEN
+          write(6,'(A)')                    "#ifdef __INTEL_OFFLOAD"
+          IF (PRESENT(Cbuffer_row).AND.PRESENT(Cbuffer_col)) THEN
+             write(6,'(A,I0,A,I0,A,I0,A)')  "!dir$ attributes offload:mic :: smm_" &
+                  //trstr(transpose_flavor,data_type)//"_", &
+                  M,"_",N,"_",K,TRIM(label)//"_buffer"
+          ELSE
+             write(6,'(A,I0,A,I0,A,I0,A)')  "!dir$ attributes offload:mic :: smm_" &
+                  //trstr(transpose_flavor,data_type)//"_", &
+                  M,"_",N,"_",K,TRIM(label)
+          ENDIF
+          write(6,'(A)')                    "#endif"
+          write(6,'(A,I0,A,I0,A,I0,A)') "   SUBROUTINE smm_"//trstr(transpose_flavor,data_type)//"_",&
+               M,"_",N,"_",K,"_stack"//TRIM(label)//"("//TRIM(trparam(stack_size_label))//")"
+          CALL write_stack_params(data_type,stack_size_label)
+          write(6,'(A)')                    "      INTEGER            :: sp"
+          IF (PRESENT(Cbuffer_row).AND.PRESENT(Cbuffer_col)) THEN
+             write(6,'(A,I0,A,I0,A)')   "       "//trdat(data_type)//":: Cbuffer(",Cbuffer_row,",",Cbuffer_col,")"
+          ENDIF
+          write(6,'(A)')                    "      DO sp = 1, "//TRIM(stack_size_label)
+          IF (PRESENT(Cbuffer_row).AND.PRESENT(Cbuffer_col)) THEN
+             write(6,'(A,I0,A,I0,A,I0,A)') "         CALL smm_"//trstr(transpose_flavor,data_type)//"_",&
+                  M,"_",N,"_",K,&
+                  TRIM(label)//"_buffer(A(params(p_a_first,sp)),B(params(p_b_first,sp)),C(params(p_c_first,sp)),Cbuffer)"
+          ELSE
+             write(6,'(A,I0,A,I0,A,I0,A)') "         CALL smm_"//trstr(transpose_flavor,data_type)//"_",&
+                  M,"_",N,"_",K,&
+                  TRIM(label)//"(A(params(p_a_first,sp)),B(params(p_b_first,sp)),C(params(p_c_first,sp)))"
+          ENDIF
+          write(6,'(A)')                  "      ENDDO"
+          write(6,'(A)') "   END SUBROUTINE"
        ENDIF
-       write(6,'(A)')                    "      DO sp = 1, "//TRIM(stack_size_label)
-       IF (PRESENT(Cbuffer_row).AND.PRESENT(Cbuffer_col)) THEN
-          write(6,'(A,I0,A,I0,A,I0,A)') "         CALL smm_"//trstr(transpose_flavor,data_type)//"_",&
-               M,"_",N,"_",K,TRIM(label)//"_buffer(A(params(p_a_first,sp)),B(params(p_b_first,sp)),C(params(p_c_first,sp)),Cbuffer)"
-       ELSE
-       write(6,'(A,I0,A,I0,A,I0,A)') "         CALL smm_"//trstr(transpose_flavor,data_type)//"_",&
-            M,"_",N,"_",K,TRIM(label)//"(A(params(p_a_first,sp)),B(params(p_b_first,sp)),C(params(p_c_first,sp)))"
-       ENDIF
-       write(6,'(A)')                  "      ENDDO"
-       write(6,'(A)') "   END SUBROUTINE"
     ENDIF
   END SUBROUTINE write_subroutine_stack
 
@@ -103,12 +119,17 @@ CONTAINS
     INTEGER :: multElements,modElements
     CHARACTER(LEN=*) :: label
     CHARACTER(LEN=*), OPTIONAL :: stack_size_label
+    LOGICAL :: do_stack
 
     multElements=(M/nSIMD)*nSIMD
     modElements=MOD(M,nSIMD)
 
     IF (modElements>0) THEN
-       if (PRESENT(stack_size_label).AND.stack_size_label/="") THEN
+       do_stack=.FALSE.
+       IF (PRESENT(stack_size_label)) THEN
+          IF (stack_size_label/="") do_stack=.TRUE.
+       ENDIF
+       IF (do_stack) THEN
           write(6,'(A,I0,A,I0,A,I0,A)')    "   PURE SUBROUTINE smm_"//trstr(transpose_flavor,data_type)//"_",&
                M,"_",N,"_",K,TRIM(label)//"_buffer(A,B,C,Cbuffer)"
           write(6,'(A,I0,A,I0,A)') "      "//trdat(data_type,"INOUT")//" :: Cbuffer(",nSIMD,",",MIN(stride,N),")"
@@ -266,13 +287,14 @@ CONTAINS
      ENDDO
      IF (ANY(best_square<1)) ERROR STOP "tiny opts file needs sufficiently many square sizes"
 
-     IF (version.ge.1.and.version.le.7) THEN
-        IF (version.ne.3) THEN
+     IF ((version.ge.1.and.version.le.7).or.version.eq.9) THEN
+        IF (version.ne.3.and.version.ne.9) THEN
            write(6,'(A,I0,A,I0,A,I0,A)')    "   PURE SUBROUTINE smm_"//trstr(transpose_flavor,data_type)//"_",&
                 M,"_",N,"_",K,TRIM(label)//"(A,B,C)"
            ELSE
               write(6,'(A,I0,A,I0,A,I0,A)')    "   SUBROUTINE smm_"//trstr(transpose_flavor,data_type)//"_",&
                    M,"_",N,"_",K,TRIM(label)//"(A,B,C)"
+              write (6,'(A)')                  "      USE, INTRINSIC :: ISO_C_BINDING"
            ENDIF
         CALL write_matrix_defs(M,N,K,transpose_flavor,data_type,.TRUE.) 
      ENDIF
@@ -298,6 +320,9 @@ CONTAINS
      CASE(3)
        ! generation of the gemm version
        WRITE(6,'(A)') "      "//trdat(data_type)//", PARAMETER :: one=1"
+       write(6,'(A)') "#ifdef __INTEL_OFFLOAD"
+       write(6,'(A)') "!dir$ attributes offload:mic :: "//trgemm(data_type)
+       write(6,'(A)') "#endif"
        SELECT CASE(transpose_flavor)
        CASE(1)
          write(6,'(A,I0,A,I0,A,I0,A,I0,A,I0,A,I0,A)') &
@@ -322,16 +347,26 @@ CONTAINS
         ! generation of the vector version
         IF (nSIMD>0) THEN
            CALL MULTVECTOR(label,M,N,K,transpose_flavor,data_type,nSIMD,stride,stack_size_label)
-           IF (PRESENT(write_buffer_interface).AND.write_buffer_interface) THEN
-              CALL MULTVECTOR(label,M,N,K,transpose_flavor,data_type,nSIMD,stride)
+           IF (PRESENT(write_buffer_interface)) THEN
+              IF (write_buffer_interface) THEN
+                 CALL MULTVECTOR(label,M,N,K,transpose_flavor,data_type,nSIMD,stride)
+              ENDIF
            ENDIF
 
         ENDIF
+     CASE(9)
+        write (6,'(A)')                "      INTERFACE"
+        write (6,'(A,I0,A,I0,A,I0,A)') "        SUBROUTINE dc_smm_dnn_",M,"_",N,"_",K,"(A,B,C) BIND(C)"
+        write (6,'(A)')                "          USE, INTRINSIC :: ISO_C_BINDING, ONLY : C_PTR"
+        write (6,'(A)')                "          TYPE(C_PTR), VALUE               :: C, B, A"
+        write (6,'(A,I0,A,I0,A,I0)')   "        END SUBROUTINE dc_smm_dnn_",M,"_",N,"_",K
+        write (6,'(A)')                "      END INTERFACE"
+        write (6,'(A,I0,A,I0,A,I0,A)') "      CALL dc_smm_dnn_",M,"_",N,"_",K,"(C_LOC(A),C_LOC(B),C_LOC(C))"
      CASE DEFAULT
        ERROR STOP "MISSING CASE mult_versions"
      END SELECT
 
-     IF (version.ge.1.and.version.le.7) THEN
+     IF ((version.ge.1.and.version.le.7).or.version.eq.9) THEN
         write(6,'(A)') "   END SUBROUTINE"
         CALL write_subroutine_stack(label,M,N,K,transpose_flavor,data_type,stack_size_label)
      ENDIF
